/* eslint-disable no-console */
import { createHighlighterCore, type HighlighterCore } from '@shikijs/core'
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript'

const DEBUG = true
function log(message: string, ...args: any[]) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args)
  }
}

let highlighterInstance: HighlighterCore | null = null

export async function getHighlighter() {
  if (highlighterInstance) {
    log('Returning cached highlighter instance')
    return highlighterInstance
  }

  try {
    log('Creating new highlighter instance...')

    log('Initializing JavaScript regex engine...')
    const engine = createJavaScriptRegexEngine({
      forgiving: true,
      simulation: true,
      cache: new Map(),
    })
    log('Engine created successfully')

    log('Loading required languages...')
    log('Languages loaded successfully')

    log('Creating highlighter core...')
    highlighterInstance = await createHighlighterCore({
      engine,
    })
    log('Highlighter core created successfully')

    log('Highlighter initialization complete')
    return highlighterInstance
  }
  catch (err) {
    log('Highlighter initialization failed:', err)
    throw err
  }
}
